/* FILE: callbacks.c
 * DESCRIPTION: Exemple GTK2+ pour afficher le contenu d'un fichier.
 * AUTHOR: Guillaume Riviere (C) 2017
 */

#include <stdio.h>
#include <string.h>  /* strcpy */
#include <stdlib.h>  /* malloc, exit */

#include <gdk/gdkkeysyms-compat.h> /* Evenements clavier/souris/... */
#include "callbacks.h"

extern GtkBuilder *builder;

void on_window1_destroy (GtkObject *object, gpointer user_data) {
  printf("Fermeture de la fenetre.\n");
  gtk_main_quit();
}

void on_window1_realize (GtkObject *object, gpointer user_data) {
  FILE *fp ;
  char *filebuf ;
  GtkTextBuffer *buf1 ;
  char filename[256] ;
  int filesize ;
  GtkTextView *view1 = GTK_TEXT_VIEW (gtk_builder_get_object (builder, "textview1"));
  GtkLabel *label1 = GTK_LABEL (gtk_builder_get_object (builder, "label1"));

  /* Nom du fichier a afficher */
  strcpy (filename, "gtk_textview_example_2.24.glade") ;

  /* Ouverture du fichier a afficher */
  if ((fp = fopen (filename, "r")) == NULL) {
    perror ("Erreur ouverture fichier") ;
    gtk_label_set_text (label1, "Pas de fichier") ;
  }
  else {

    /* Taille du fichier en octets */
    fseek (fp, 0, SEEK_END); /* Postionner au dernier octet du fichier */
    filesize = ftell (fp);   /* Recuperer la position */
    fseek (fp, 0, SEEK_SET); /* Revenir au premier octet du fichier */

    /* Allouer tampon pour les octets du fichier */
    if ((filebuf = (char *)malloc (filesize)) == NULL) {
      perror ("Erreur allocation memoire") ;
      exit (1) ;
    }

    /* Lecture du fichier dans le tampon */
    fread (filebuf, 1, filesize, fp);

    /* Fermeture du fichier */
    fclose (fp) ;

    /* Affichage dans l'interface */
    buf1 = gtk_text_view_get_buffer (view1) ;
    gtk_text_buffer_set_text (buf1, filebuf, filesize) ;
    gtk_label_set_text (label1, filename) ;

    /* Liberer la memoire du tampon */
    free (filebuf) ;
  }
}
